xsdata.codegen.handlers.attribute\_enum\_union module
=====================================================

.. automodule:: xsdata.codegen.handlers.attribute_enum_union
   :members:
   :undoc-members:
   :show-inheritance:
